@@ -39,7 +39,9 @@ class FootprintBasisFunction(BaseBasisFunction):
     out_of_bounds_val : `float`, optional
         The value to set the basis function for regions that are not in
         the footprint. Default -10, np.nan is another good value to use.
-
+    seeing_fwhm_max : `float`
+        Seeing limit to use (arcsec) when counting observations.
+        Default None.
     """
 
     def __init__(
@@ -49,6 +51,7 @@ class FootprintBasisFunction(BaseBasisFunction):
         footprint=None,
         out_of_bounds_val=-10.0,
         filtername=None,
+        seeing_fwhm_max=None,
     ):
         if filtername is not None:
             warnings.warn("filtername deprecated in favor of bandname", FutureWarning)
@@ -67,8 +70,12 @@ class FootprintBasisFunction(BaseBasisFunction):
 
         self.survey_features = {}
         # All the observations in all bands
-        self.survey_features["N_obs_all"] = features.NObservations(nside=self.nside, bandname=None)
-        self.survey_features["N_obs"] = features.NObservations(nside=self.nside, bandname=bandname)
+        self.survey_features["N_obs_all"] = features.NObservations(
+            nside=self.nside, bandname=None, seeing_limit=seeing_fwhm_max
+        )
+        self.survey_features["N_obs"] = features.NObservations(
+            nside=self.nside, bandname=bandname, seeing_limit=seeing_fwhm_max
+        )
 
         # should probably actually loop over all the target maps?
         self.out_of_bounds_area = np.where(footprint.get_footprint(self.bandname) <= 0)[0]
